@@ -12,7 +12,7 @@ use List::MoreUtils qw/uniq/;
 # TODO : experiment with bit vectors (cf vec() and pack "b*" for combining 
 #        result sets
 
-our $VERSION = "0.76";
+our $VERSION = "0.77";
 
 =head1 NAME
 
@@ -523,8 +523,13 @@ sub dump {
   my $self = shift;
   foreach my $word (sort keys %{$self->{ixw}}) {
     my $wordId = $self->{ixw}{$word};
-    my %docs = unpack IXDPACK_L, $self->{ixd}{$wordId};
-    print "$word : ", join (" ", keys %docs), "\n";
+    if ($wordId == -1) {
+      print "$word : STOPWORD\n";
+    }
+    else {
+      my %docs = unpack IXDPACK_L, $self->{ixd}{$wordId};
+      print "$word : ", join (" ", keys %docs), "\n";
+    }
   }
 }
 
